==> aliyun-java-sdk-vpc-3.2.10-sources.jar: com/aliyuncs/vpc/transform/v20160428/CreateVpcGatewayEndpointResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.transform.v20160428;

import com.aliyuncs.vpc.model.v20160428.CreateVpcGatewayEndpointResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class CreateVpcGatewayEndpointResponseUnmarshaller {

	public static CreateVpcGatewayEndpointResponse unmarshall(CreateVpcGatewayEndpointResponse createVpcGatewayEndpointResponse, UnmarshallerContext _ctx) {
		
		createVpcGatewayEndpointResponse.setRequestId(_ctx.stringValue("CreateVpcGatewayEndpointResponse.RequestId"));
		createVpcGatewayEndpointResponse.setEndpointId(_ctx.stringValue("CreateVpcGatewayEndpointResponse.EndpointId"));
		createVpcGatewayEndpointResponse.setServiceName(_ctx.stringValue("CreateVpcGatewayEndpointResponse.ServiceName"));
		createVpcGatewayEndpointResponse.setEndpointName(_ctx.stringValue("CreateVpcGatewayEndpointResponse.EndpointName"));
		createVpcGatewayEndpointResponse.setCreationTime(_ctx.stringValue("CreateVpcGatewayEndpointResponse.CreationTime"));
	 
	 	return createVpcGatewayEndpointResponse;
	}
}

==> aliyun-java-sdk-vpc-3.2.28-sources.jar: com/aliyuncs/vpc/transform/v20160428/CreateVpcGatewayEndpointResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.transform.v20160428;

import com.aliyuncs.vpc.model.v20160428.CreateVpcGatewayEndpointResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class CreateVpcGatewayEndpointResponseUnmarshaller {

	public static CreateVpcGatewayEndpointResponse unmarshall(CreateVpcGatewayEndpointResponse createVpcGatewayEndpointResponse, UnmarshallerContext _ctx) {
		
		createVpcGatewayEndpointResponse.setRequestId(_ctx.stringValue("CreateVpcGatewayEndpointResponse.RequestId"));
		createVpcGatewayEndpointResponse.setEndpointId(_ctx.stringValue("CreateVpcGatewayEndpointResponse.EndpointId"));
		createVpcGatewayEndpointResponse.setServiceName(_ctx.stringValue("CreateVpcGatewayEndpointResponse.ServiceName"));
		createVpcGatewayEndpointResponse.setEndpointName(_ctx.stringValue("CreateVpcGatewayEndpointResponse.EndpointName"));
		createVpcGatewayEndpointResponse.setCreationTime(_ctx.stringValue("CreateVpcGatewayEndpointResponse.CreationTime"));
		createVpcGatewayEndpointResponse.setResourceGroupId(_ctx.stringValue("CreateVpcGatewayEndpointResponse.ResourceGroupId"));
	 
	 	return createVpcGatewayEndpointResponse;
	}
}
